@@ -129,7 +129,7 @@ def cli_deploy(ctx):
 @main.command("rollback", help="Rollback in produzione")
 @click.pass_context
 def cli_rollback(ctx):
-    rollback.entrypoint(ctx.obj["project"])
+    rollback.entrypoint(ctx.obj["project"], ctx.obj["captainhook_timeout"])
 
 
 @main.command("status", help="Stato attuale di un progetto")
