@@ -17,7 +17,9 @@ config = Config()
 
 
 def entrypoint(project, card):
-    git.is_dirty(project)
+    if git.is_dirty(project):
+        logger.error("Hai modifiche non committate, non posso continuare")
+        sys.exit(-1)
 
     try:
         if card:
