@@ -1,14 +1,19 @@
 # -*- encoding: utf-8 -*-
 from distutils.version import StrictVersion
+from os import environ
 import time
+import subprocess
+from subprocess import CalledProcessError
+import sys
 import requests
 
 from halo import Halo
 from suite_py.lib.tokens import Tokens
+from suite_py.lib.logger import Logger
 
-
-tokens = Tokens()
-baseurl = "https://drone-1.prima.it"
+logger = Logger()
+drone_token = environ["DRONE_TOKEN"] = Tokens().drone
+baseurl = environ["DRONE_SERVER"] = "https://drone-1.prima.it"
 
 
 def get_last_build_url(repo, prefix=None):
@@ -18,7 +23,7 @@ def get_last_build_url(repo, prefix=None):
         try:
             builds = requests.get(
                 f"{baseurl}/api/repos/primait/{repo}/builds",
-                headers={"Authorization": f"Bearer {tokens.drone}"},
+                headers={"Authorization": f"Bearer {drone_token}"},
             ).json()
 
             if prefix:
@@ -37,7 +42,7 @@ def get_pr_build_number(repo, commit_sha):
             try:
                 builds = requests.get(
                     f"{baseurl}/api/repos/primait/{repo}/builds?per_page=100",
-                    headers={"Authorization": f"Bearer {tokens.drone}"},
+                    headers={"Authorization": f"Bearer {drone_token}"},
                 ).json()
                 builds = [b for b in builds if b["after"] == commit_sha]
                 return builds[0]["number"]
@@ -50,7 +55,7 @@ def get_pr_build_number(repo, commit_sha):
 def get_user():
     try:
         user = requests.get(
-            f"{baseurl}/api/user", headers={"Authorization": f"Bearer {tokens.drone}"},
+            f"{baseurl}/api/user", headers={"Authorization": f"Bearer {drone_token}"},
         ).json()
         return user
     except Exception:
@@ -67,7 +72,7 @@ def get_tag_from_builds(repo):
     tags = []
     builds = requests.get(
         f"{baseurl}/api/repos/primait/{repo}/builds?per_page=100",
-        headers={"Authorization": f"Bearer {tokens.drone}"},
+        headers={"Authorization": f"Bearer {drone_token}"},
     ).json()
 
     for build in builds:
@@ -82,7 +87,7 @@ def get_tag_from_builds(repo):
 def get_build_from_tag(repo, tag):
     builds = requests.get(
         f"{baseurl}/api/repos/primait/{repo}/builds?per_page=100",
-        headers={"Authorization": f"Bearer {tokens.drone}"},
+        headers={"Authorization": f"Bearer {drone_token}"},
     ).json()
 
     for build in builds:
@@ -95,7 +100,7 @@ def get_build_from_tag(repo, tag):
 def launch_build(repo, build):
     return requests.post(
         f"{baseurl}/api/repos/primait/{repo}/builds/{build}",
-        headers={"Authorization": f"Bearer {tokens.drone}"},
+        headers={"Authorization": f"Bearer {drone_token}"},
     ).json()
 
 
@@ -106,7 +111,7 @@ def prestart_success(repo, build_number):
             tries -= 1
             build_status = requests.get(
                 f"{baseurl}/api/repos/primait/{repo}/builds/{build_number}",
-                headers={"Authorization": f"Bearer {tokens.drone}"},
+                headers={"Authorization": f"Bearer {drone_token}"},
             ).json()
 
             steps = build_status["stages"][0]["steps"]
@@ -118,3 +123,31 @@ def prestart_success(repo, build_number):
                     break
             time.sleep(3)
         return False
+
+
+def fmt(project, path):
+    try:
+        subprocess.run(["drone", "fmt", "--save", ".drone.yml"], cwd=path, check=True)
+    except (CalledProcessError) as e:
+        logger.error(f"{project}: non sono riuscito a formattare il .drone.yml {e}")
+        sys.exit(-1)
+
+
+def validate(project, path):
+    try:
+        subprocess.run(
+            ["drone", "lint", "--trusted", ".drone.yml"], cwd=path, check=True
+        )
+    except (CalledProcessError) as e:
+        logger.error(f"{project}: il .drone.yml non è valido {e}")
+        sys.exit(-1)
+
+
+def sign(project, path):
+    try:
+        subprocess.run(
+            ["drone", "sign", f"primait/{project}", "--save"], cwd=path, check=True,
+        )
+    except (CalledProcessError) as e:
+        logger.error(f"{project}: non sono riuscito a firmare il .drone.yml {e}")
+        sys.exit(-1)
